@@ -14,9 +14,10 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.0.8'
+__version__ = '0.0.9'
 
 
+from mock import patch
 from logging import getLogger
 from unittest import TestCase
 from types import ModuleType
@@ -59,18 +60,19 @@ class UnitTests(TestCase):
         pass
 
 
-class Targetting(object):
+class FluentTargeting(object):
 
     def __init__(self, target):
-        if not isinstance(target, ModuleType):
-            self._target_name = type(target).__name__
-            self._target = target
-        else:
+        if isinstance(target, ModuleType):
             self._target_name = target.__name__
             self._target = __import__(self._target_name)
+        else:
+            target_type = type(target)
+            self._target_name = target_type.__module__ + '.' + target_type.__name__
+            self._target = target
 
 
-class Answer(object):
+class FluentAnswer(object):
 
     def __init__(self, arguments):
         self.arguments = arguments
@@ -93,20 +95,26 @@ class Answer(object):
         return "Answer(argument={argument}, values={values})".format(argument=self.arguments, values=self._values)
 
 
-class StubEntry(object):
+class FluentStubEntry(FluentTargeting):
 
-    def __init__(self, target, attribute, original):
-        self._target = target
-        self._attribute = attribute
+    def __init__(self, target, attribute_name, original):
+        FluentTargeting.__init__(self, target)
+        self._attribute_name = attribute_name
         self._original = original
+        self._patch = None
+
+    def stub_away_with(self, fluent_mock):
+        full_qualified_target_name = self._target_name + '.' + self._attribute_name
+        self._patch = patch(full_qualified_target_name).__enter__()
+        self._patch.side_effect = fluent_mock
 
     def unstub(self):
-        setattr(self._target, self._attribute, self._original)
+        setattr(self._target, self._attribute_name, self._original)
 
 
-class CallEntry(Targetting):
+class FluentCallEntry(FluentTargeting):
     def __init__(self, target, attribute, arguments):
-        Targetting.__init__(self, target)
+        FluentTargeting.__init__(self, target)
         self._attribute_name = attribute
         self._arguments = arguments
 
@@ -129,15 +137,15 @@ class CallEntry(Targetting):
                                                                          arguments=arguments)
 
 
-class Mock(Targetting):
+class FluentMock(FluentTargeting):
 
     def __init__(self, target, attribute_name):
-        Targetting.__init__(self, target)
+        FluentTargeting.__init__(self, target)
         self._attribute_name = attribute_name
         self._answers = []
 
     def __call__(self, *arguments):
-        _calls.append(CallEntry(self._target, self._attribute_name, arguments))
+        _calls.append(FluentCallEntry(self._target, self._attribute_name, arguments))
 
         if not self._answers:
             return None
@@ -155,7 +163,7 @@ class Mock(Targetting):
         return "Mock(" + str(self._answers) + ")"
 
 
-class MockConfigurator(object):
+class FluentMockConfigurator(object):
 
     def __init__(self, mock):
         self._mock = mock
@@ -164,15 +172,15 @@ class MockConfigurator(object):
 
     def __call__(self, *arguments):
         self._arguments = arguments
-        self._answer = Answer(self._arguments)
+        self._answer = FluentAnswer(self._arguments)
         self._mock.append_new_answer(self._answer)
         return self._answer
 
 
-class Mocker(Targetting):
+class FluentWhen(FluentTargeting):
 
     def __init__(self, target):
-        Targetting.__init__(self, target)
+        FluentTargeting.__init__(self, target)
 
     def __getattr__(self, name):
         if not hasattr(self._target, name):
@@ -180,22 +188,23 @@ class Mocker(Targetting):
                                                                        attribute_name=name))
 
         original = getattr(self._target, name)
-        _stubs.append(StubEntry(self._target, name, original))
+        stub_entry = FluentStubEntry(self._target, name, original)
+        _stubs.append(stub_entry)
 
         key = (self._target, name)
         if not key in _configurators:
-            mock = Mock(self._target, name)
-            mock_configurator = MockConfigurator(mock)
-            setattr(self._target, name, mock)
+            fluent_mock = FluentMock(self._target, name)
+            mock_configurator = FluentMockConfigurator(fluent_mock)
+            stub_entry.stub_away_with(fluent_mock)
             _configurators[key] = mock_configurator
 
         return _configurators[key]
 
 
-class Verifier(Targetting):
+class Verifier(FluentTargeting):
 
     def __init__(self, target):
-        Targetting.__init__(self, target)
+        FluentTargeting.__init__(self, target)
         self._attribute_name = None
 
     def __getattr__(self, name):
@@ -222,7 +231,7 @@ class Verifier(Targetting):
 
         number_of_found_calls = len(found_calls)
         if number_of_found_calls > 0:
-            expected_call_entry = CallEntry(self._target, self._attribute_name, arguments)
+            expected_call_entry = FluentCallEntry(self._target, self._attribute_name, arguments)
             error_message = MESSAGE_EXPECTED_BUT_WAS.format(expected=expected_call_entry, actual=found_calls[0])
             if number_of_found_calls > 1:
                 for call in found_calls[1:]:
@@ -240,7 +249,7 @@ class FluentMockException(Exception):
 
 
 def when(target):
-    return Mocker(target)
+    return FluentWhen(target)
 
 
 def unstub():
